<div align="center">
    <img src="../../docs/images/logo-title.png" height="80px">
    <h3>The Graph Of LIfe Library.</h3>
</div>


## What is in this folder? 

code for IPU acceleration support

- `ipu_dataloader.py`: code for handling dataloader on IPU
- `ipu_losses.py`: code for computing losses on IPU
- `ipu_simple_lightning.py`: code for pytorch lightning support on IPU
- `ipu_utils.py`: utils functions for IPU
- `ipu_wrapper.py`: wrapper code for IPU support 